@@ -3,6 +3,7 @@
 #' This function performs a Factor Analysis (FA).
 #'
 #' @inheritParams principal_components
+#' @inheritParams n_factors
 #'
 #' @details
 #'  \subsection{Complexity}{
@@ -16,8 +17,8 @@
 #'  There is a simplified rule of thumb that may help do decide whether to run
 #'  a principal component analysis or a factor analysis:
 #'  \itemize{
-#'    \item Run principal component analysis if you assume or wish to test a theoretical model of latent factors causing observed variables.
-#'    \item Run factor analysis If you want to simply reduce your correlated observed variables to a smaller set of important independent composite variables.
+#'    \item Run \emph{factor analysis} if you assume or wish to test a theoretical model of latent factors causing observed variables.
+#'    \item Run \emph{principal component analysis} If you want to simply reduce your correlated observed variables to a smaller set of important independent composite variables.
 #'  }
 #'  (Source: \href{https://stats.stackexchange.com/q/1576/54740}{CrossValidated})
 #'  }
@@ -46,7 +47,7 @@
 #' }
 #' @importFrom stats prcomp
 #' @export
-factor_analysis <- function(x, n = "auto", rotation = "none", sort = FALSE, threshold = NULL, standardize = TRUE, ...) {
+factor_analysis <- function(x, n = "auto", rotation = "none", sort = FALSE, threshold = NULL, standardize = TRUE, cor = NULL, ...) {
   UseMethod("factor_analysis")
 }
 
@@ -54,17 +55,17 @@ factor_analysis <- function(x, n = "auto", rotation = "none", sort = FALSE, thre
 
 #' @importFrom stats prcomp na.omit
 #' @export
-factor_analysis.data.frame <- function(x, n = "auto", rotation = "none", sort = FALSE, threshold = NULL, standardize = TRUE, ...) {
+factor_analysis.data.frame <- function(x, n = "auto", rotation = "none", sort = FALSE, threshold = NULL, standardize = TRUE, cor = NULL, ...) {
 
   # Standardize
-  if (standardize) {
+  if (standardize && is.null(cor)) {
     x <- as.data.frame(scale(x))
   }
 
   # N factors
-  n <- .get_n_factors(x, n = n, type = "FA", rotation = rotation)
+  n <- .get_n_factors(x, n = n, type = "FA", rotation = rotation, cor = cor)
 
-  .FA_rotate(x, n, rotation = rotation, sort = sort, threshold = threshold, ...)
+  .FA_rotate(x, n, rotation = rotation, sort = sort, threshold = threshold, cor = cor, ...)
 }
 
 
@@ -73,7 +74,7 @@ factor_analysis.data.frame <- function(x, n = "auto", rotation = "none", sort =
 
 
 #' @keywords internal
-.FA_rotate <- function(x, n, rotation, sort = FALSE, threshold = NULL, ...) {
+.FA_rotate <- function(x, n, rotation, sort = FALSE, threshold = NULL, cor = NULL, ...) {
   if (!(rotation %in% c("varimax", "quartimax", "promax", "oblimin", "simplimax", "cluster", "none"))) {
     stop("`rotation` must be one of \"varimax\", \"quartimax\", \"promax\", \"oblimin\", \"simplimax\", \"cluster\" or \"none\".")
   }
@@ -87,5 +88,15 @@ factor_analysis.data.frame <- function(x, n = "auto", rotation = "none", sort =
     stop(sprintf("Package `psych` required for `%s`-rotation.", rotation), call. = FALSE)
   }
 
-  model_parameters(psych::fa(x, nfactors = n, rotate = rotation, ...), sort = sort, threshold = threshold)
+  # Pass cor if available
+  if(!is.null(cor)) {
+    out <- model_parameters(psych::fa(cor, nfactors = n, rotate = rotation, n.obs = nrow(x), ...), sort = sort, threshold = threshold)
+  } else{
+    out <- model_parameters(psych::fa(x, nfactors = n, rotate = rotation, ...), sort = sort, threshold = threshold)
+  }
+
+
+
+  attr(out, "data_set") <- x
+  out
 }
