@@ -110,8 +110,73 @@ model_parameters.rma <- function(model, ci = .95, bootstrap = FALSE, iterations
 
   # no df
   out$df_error <- NULL
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- .safe_deparse(substitute(model))
   attr(out, "measure") <- model$measure
 
   out
 }
+
+
+
+
+
+#' @export
+model_parameters.metaplus <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, standardize = NULL, exponentiate = FALSE, ...) {
+  meta_analysis_overall <- suppressWarnings(.model_parameters_generic(
+    model = model,
+    ci = ci,
+    bootstrap = bootstrap,
+    iterations = iterations,
+    merge_by = "Parameter",
+    standardize = standardize,
+    exponentiate = exponentiate,
+    ...
+  ))
+
+  rma_parameters <- if (!is.null(model$slab) && !is.numeric(model$slab)) {
+    sprintf("%s", model$slab)
+  } else {
+    sprintf("Study %i", 1:model[["k"]])
+  }
+
+  alpha <- (1 + ci) / 2
+
+  rma_coeffients <- as.vector(model$yi)
+  rma_se <- as.vector(model$sei)
+  rma_ci_low <- rma_coeffients - rma_se * stats::qt(alpha, df = Inf)
+  rma_ci_high <- rma_coeffients + rma_se * stats::qt(alpha, df = Inf)
+  rma_statistic <- rma_coeffients / rma_se
+  rma_ci_p <- 2 * stats::pt(abs(rma_statistic), df = Inf, lower.tail = FALSE)
+
+  meta_analysis_studies <- data.frame(
+    Parameter = rma_parameters,
+    Coefficient = rma_coeffients,
+    SE = rma_se,
+    CI_low = rma_ci_low,
+    CI_high = rma_ci_high,
+    z = rma_statistic,
+    df_error = NA,
+    p = rma_ci_p,
+    Weight = 1 / as.vector(model$sei),
+    stringsAsFactors = FALSE
+  )
+
+  original_attributes <- attributes(meta_analysis_overall)
+  out <- merge(meta_analysis_studies, meta_analysis_overall, all = TRUE, sort = FALSE)
+
+  # fix intercept name
+  out$Parameter[out$Parameter == "(Intercept)"] <- "Overall"
+  out <- out[out$Parameter != "tau2", ]
+
+  original_attributes$names <- names(out)
+  original_attributes$row.names <- 1:nrow(out)
+  original_attributes$pretty_names <- stats::setNames(out$Parameter, out$Parameter)
+  attributes(out) <- original_attributes
+
+  # no df
+  out$df_error <- NULL
+  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "measure") <- "Estimate"
+
+  out
+}
